//
//  NSString+Extension.m
//  FMNewProject
//
//  Created by LBS_ios1 on 2017/12/28.
//  Copyright © 2017年 http://www.jianshu.com/u/8acc5c21e350. All rights reserved.
//


#import "NSString+Extension.h"
#import <CommonCrypto/CommonDigest.h>
@implementation NSString (Extension)
/**
 返回文字具体占据的实际的大小
 
 @param purposeSize 估算的大小
 @param font 字体
 @return 返回实际的文字的大小
 */
- (CGSize)targetSizeForTextWithpurposeSize:(CGSize)purposeSize WithTextFont:(UIFont *)font {
    //设置计算文本时字体的大小,以什么标准来计算
    NSDictionary *attrbute = @{NSFontAttributeName:font};
    
    return [self boundingRectWithSize:purposeSize options:(NSStringDrawingUsesFontLeading | NSStringDrawingUsesLineFragmentOrigin) attributes:attrbute context:nil].size;
}
/**
 将总秒数转化成时分秒字符串
 */
+ (instancetype)timeFormatted:(NSInteger)totalSeconds {
    NSInteger seconds = totalSeconds % 60;
    NSInteger minutes = (totalSeconds / 60) % 60;
    NSInteger hours = totalSeconds / 3600;
    
    return [NSString stringWithFormat:@"%02ld:%02ld:%02ld",hours, minutes, seconds];
}
/**
 将第三方跑步的总秒数转化成时分秒字符串
 */
+ (instancetype)thirdRunDataHoursFormatted:(NSInteger)totalSeconds {
    NSInteger seconds = totalSeconds % 60;
    NSInteger minutes = (totalSeconds / 60) % 60;
    NSInteger hours = totalSeconds / 3600;
    return [NSString stringWithFormat:@"%02ld:%02ld:%02ld",hours, minutes, seconds];
}
/**
 将总秒数转化成时分秒字符串
 */
+ (instancetype)hoursFormatted:(NSInteger)totalSeconds {
    NSInteger seconds = totalSeconds % 60;
    NSInteger minutes = (totalSeconds / 60) % 60;
    NSInteger hours = totalSeconds / 3600;
    if (hours) {
        return [NSString stringWithFormat:@"%02ld:%02ld:%02ld",hours, minutes, seconds];
    }
    return [NSString stringWithFormat:@"%02ld:%02ld",  minutes, seconds];
}

/**
 将总秒数转化成分秒字符串
 */
+ (instancetype)minuteTimeFormatted:(NSInteger)totalSeconds {
    NSInteger seconds = totalSeconds % 60;
    NSInteger minutes = (totalSeconds / 60) % 60;
     NSInteger hours = totalSeconds / 3600;
     minutes += hours * 60;
    return [NSString stringWithFormat:@"%02ld'%02ld''",  minutes, seconds];
}
/**
 使用MD5 进行加密方法
 */
+ (NSString *)md5:(NSString *)str
{
    const char *cStr = [str UTF8String];
    unsigned char result[16];
    CC_MD5(cStr, strlen(cStr), result); // This is the md5 call
    return [NSString stringWithFormat:
            @"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
            result[0], result[1], result[2], result[3],
            result[4], result[5], result[6], result[7],
            result[8], result[9], result[10], result[11],
            result[12], result[13], result[14], result[15]
            ];
}
/**
 使用MD5大写加密
 */
- (NSString*)md532BitUpper {
    const char *cStr = [self UTF8String];
    unsigned char result[16];
    
    NSNumber *num = [NSNumber numberWithUnsignedLong:strlen(cStr)];
    CC_MD5( cStr,[num intValue], result );
    
    return [[NSString stringWithFormat:
             @"%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X%02X",
             result[0], result[1], result[2], result[3],
             result[4], result[5], result[6], result[7],
             result[8], result[9], result[10], result[11],
             result[12], result[13], result[14], result[15]
             ] uppercaseString];

}
/**
 得道指定文件的大小（文件的所占的字节数）
 */
- (long long) getFileSize {
    //文件管理者
    NSFileManager *fileManager = [NSFileManager defaultManager];
    //文件的总的大小
    long long fileSize = 0.0;
    for (NSString *filepaths in [fileManager subpathsAtPath:self]) {
        //文件的总路径
        NSString *path = [self stringByAppendingPathComponent:filepaths];
        BOOL isDirectory;
        [fileManager fileExistsAtPath:path isDirectory:&isDirectory];
        //添加当前文件的大小
        if (isDirectory) {
            continue;
        }
        //文件的属性
        fileSize +=[fileManager attributesOfItemAtPath:path error:nil].fileSize;
        
    }
    return fileSize;
}
/**
 获取时间的秒数
 */
- (NSInteger) getTimeSeconds {
    NSArray *timeArr = [self componentsSeparatedByString:@":"];
    NSInteger timeSeconds = 0;
    NSString *hourStr = timeArr.firstObject;
    NSString *minuteStr = timeArr[1];
    NSString *secondStr = timeArr.lastObject;
    timeSeconds += (hourStr.integerValue * 3600 + minuteStr.integerValue * 60 + secondStr.integerValue);
    return timeSeconds;
}
@end
